Documentation
¶
Index ¶
- Constants
- type Client
- func (cli *Client) CloseConnection_Aux(normalExit bool) (cerr *ce.CommonError)
- func (cli *Client) CloseConnection_Main(normalExit bool) (cerr *ce.CommonError)
- func (cli *Client) ForgetRecord(uid string) (cerr *ce.CommonError)
- func (cli *Client) GetAuxDsn() (dsn string)
- func (cli *Client) GetId() (id string)
- func (cli *Client) GetMainDsn() (dsn string)
- func (cli *Client) ResetCache() (cerr *ce.CommonError)
- func (cli *Client) Restart(forcibly bool) (cerr *ce.CommonError)
- func (cli *Client) SearchFile(uid string) (fileExists bool, cerr *ce.CommonError)
- func (cli *Client) SearchRecord(uid string) (recExists bool, cerr *ce.CommonError)
- func (cli *Client) ShowData(uid string) (data []byte, cerr *ce.CommonError)
- func (cli *Client) Start() (cerr *ce.CommonError)
- func (cli *Client) Stop() (cerr *ce.CommonError)
Constants ¶
const ( // ClientIdNone is a client ID for a non-network operations. ClientIdNone = "" // ClientIdIncoming is a client ID for a request incoming to server. ClientIdIncoming = "s" )
const ( ErrDoubleStartIsNotPossible = "double start is not possible" ErrDoubleStopIsNotPossible = "double stop is not possible" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client is client.
func (*Client) CloseConnection_Aux ¶
func (cli *Client) CloseConnection_Aux(normalExit bool) (cerr *ce.CommonError)
CloseConnection_Aux tells the server to close the auxiliary connection. Returns a detailed error.
func (*Client) CloseConnection_Main ¶
func (cli *Client) CloseConnection_Main(normalExit bool) (cerr *ce.CommonError)
CloseConnection_Main tells the server to close the main connection. Returns a detailed error.
func (*Client) ForgetRecord ¶
func (cli *Client) ForgetRecord(uid string) (cerr *ce.CommonError)
ForgetRecord requests the server to remove a data entry from cache. Returns a detailed error.
func (*Client) GetMainDsn ¶
GetMainDsn returns the DSN of the main connection of the client.
func (*Client) ResetCache ¶
func (cli *Client) ResetCache() (cerr *ce.CommonError)
ResetCache requests the server to remove all entries from cache. Returns a detailed error.
func (*Client) Restart ¶
func (cli *Client) Restart(forcibly bool) (cerr *ce.CommonError)
Restart re-starts the client.
func (*Client) SearchFile ¶
func (cli *Client) SearchFile(uid string) (fileExists bool, cerr *ce.CommonError)
SearchFile asks server to check existence of a file. Returns a detailed error.
func (*Client) SearchRecord ¶
func (cli *Client) SearchRecord(uid string) (recExists bool, cerr *ce.CommonError)
SearchRecord asks server to check existence of a data record in cache. Returns a detailed error.